@@ -397,6 +397,14 @@ class BaseNode:
             self._wrapper_telnet_server.close()
             await self._wrapper_telnet_server.wait_closed()
 
+    async def reset_console(self):
+        """
+        Reset console
+        """
+
+        await self.stop_wrap_console()
+        await self.start_wrap_console()
+
     async def start_websocket_console(self, request):
         """
         Connect to console using Websocket.
@@ -570,8 +578,12 @@ class BaseNode:
                 # no need to allocate a port when the console type is none
                 self._console = None
             elif console_type == "vnc":
-                # VNC is a special case and the range must be 5900-6000
-                self._console = self._manager.port_manager.get_free_tcp_port(self._project, 5900, 6000)
+                vnc_console_start_port_range, vnc_console_end_port_range = self._get_vnc_console_port_range()
+                self._console = self._manager.port_manager.get_free_tcp_port(
+                    self._project,
+                    vnc_console_start_port_range,
+                    vnc_console_end_port_range
+                )
             else:
                 self._console = self._manager.port_manager.get_free_tcp_port(self._project)
 
@@ -770,18 +782,8 @@ class BaseNode:
             # on Linux we use RAW sockets by default excepting if host traffic must be blocked
             await self._ubridge_send('bridge add_nio_linux_raw {name} "{interface}"'.format(name=bridge_name, interface=ethernet_interface))
         elif sys.platform.startswith("win"):
-            # on Windows we use Winpcap/Npcap
-            windows_interfaces = interfaces()
-            npf_id = None
-            source_mac = None
-            for interface in windows_interfaces:
-                # Winpcap/Npcap uses a NPF ID to identify an interface on Windows
-                if "netcard" in interface and ethernet_interface in interface["netcard"]:
-                    npf_id = interface["id"]
-                    source_mac = interface["mac_address"]
-                elif ethernet_interface in interface["name"]:
-                    npf_id = interface["id"]
-                    source_mac = interface["mac_address"]
+            npf_id, source_mac = self._find_windows_interface(ethernet_interface)
+
             if npf_id:
                 await self._ubridge_send('bridge add_nio_ethernet {name} "{interface}"'.format(name=bridge_name,
                                                                                                     interface=npf_id))
@@ -805,6 +807,25 @@ class BaseNode:
                 await self._ubridge_send('bridge set_pcap_filter {name} "not ether src {mac}"'.format(name=bridge_name, mac=source_mac))
                 log.info('PCAP filter applied on "{interface}" for source MAC {mac}'.format(interface=ethernet_interface, mac=source_mac))
 
+    @staticmethod
+    def _find_windows_interface(ethernet_interface):
+        """
+        Get NPF ID and MAC address by input ethernet interface name.
+        Return None, None when not match any interface
+
+        :returns: NPF ID and MAC address
+        """
+        # on Windows we use Winpcap/Npcap
+        windows_interfaces = interfaces()
+        for interface in windows_interfaces:
+            if str.strip(ethernet_interface) == str.strip(interface["name"]):
+                return interface["id"], interface["mac_address"]
+
+        for interface in windows_interfaces:
+            if "netcard" in interface and ethernet_interface in interface["netcard"]:
+                return interface["id"], interface["mac_address"]
+        return None, None
+
     def _create_local_udp_tunnel(self):
         """
         Creates a local UDP tunnel (pair of 2 NIOs, one for each direction)
